ALL_WINDOWS_SCREENED = "1"
BROTHER_SISTER = "BROTHER_SISTER"
CHF = "chf"
FAMILY_OWNED = "family_owned"
GRANDCHILD = "GRANDCHILD"
JOINT_OWNED = "joint_owned"
NHIF = "nhif"
NON_FAMILY_OWNED = "nonfamily_owned"
OWNER = "owner"
PARENT = "PARENT"
PARENTINLAW = "PARENTINLAW"
SOME_WINDOWS_SCREENED = "2"
SON_DAUGHTER = "SON_DAUGHTER"
SON_DAUGHTERINLAW = "SON_DAUGHTERINLAW"
WIFE_HUSBAND = "WIFE_HUSBAND"
