# Generated by Django 4.2.3 on 2023-08-07 23:19

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("edc_he", "0013_alter_healtheconomicsassets_bedrooms_and_more"),
    ]

    operations = [
        migrations.RenameField(
            model_name="healtheconomicsincome",
            old_name="external_remittance",
            new_name="external_remit",
        ),
        migrations.RenameField(
            model_name="healtheconomicsincome",
            old_name="external_remittance_value_known",
            new_name="external_remit_value_known",
        ),
        migrations.RenameField(
            model_name="healtheconomicsincome",
            old_name="internal_remittance",
            new_name="internal_remit",
        ),
        migrations.RenameField(
            model_name="healtheconomicsincome",
            old_name="internal_remittance_value_known",
            new_name="internal_remit_value_known",
        ),
        migrations.RenameField(
            model_name="historicalhealtheconomicsincome",
            old_name="external_remittance",
            new_name="external_remit",
        ),
        migrations.RenameField(
            model_name="historicalhealtheconomicsincome",
            old_name="external_remittance_value_known",
            new_name="external_remit_value_known",
        ),
        migrations.RenameField(
            model_name="historicalhealtheconomicsincome",
            old_name="internal_remittance",
            new_name="internal_remit",
        ),
        migrations.RenameField(
            model_name="historicalhealtheconomicsincome",
            old_name="internal_remittance_value_known",
            new_name="internal_remit_value_known",
        ),
        migrations.RemoveField(
            model_name="healtheconomicsincome",
            name="external_remittance_value",
        ),
        migrations.RemoveField(
            model_name="healtheconomicsincome",
            name="internal_remittance_value",
        ),
        migrations.RemoveField(
            model_name="historicalhealtheconomicsincome",
            name="external_remittance_value",
        ),
        migrations.RemoveField(
            model_name="historicalhealtheconomicsincome",
            name="internal_remittance_value",
        ),
        migrations.AddField(
            model_name="healtheconomicsincome",
            name="external_remit_value",
            field=models.IntegerField(
                blank=True,
                help_text="Use cash equivalent in local currency",
                null=True,
                verbose_name="Estimated <u>total amount of income</u> from this source over the time period from above",
            ),
        ),
        migrations.AddField(
            model_name="healtheconomicsincome",
            name="internal_remit_value",
            field=models.IntegerField(
                blank=True,
                help_text="Use cash equivalent in local currency",
                null=True,
                verbose_name="Estimated <u>total amount of income</u> from this source over the time period from above",
            ),
        ),
        migrations.AddField(
            model_name="historicalhealtheconomicsincome",
            name="external_remit_value",
            field=models.IntegerField(
                blank=True,
                help_text="Use cash equivalent in local currency",
                null=True,
                verbose_name="Estimated <u>total amount of income</u> from this source over the time period from above",
            ),
        ),
        migrations.AddField(
            model_name="historicalhealtheconomicsincome",
            name="internal_remit_value",
            field=models.IntegerField(
                blank=True,
                help_text="Use cash equivalent in local currency",
                null=True,
                verbose_name="Estimated <u>total amount of income</u> from this source over the time period from above",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsassets",
            name="dwelling_value_known",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("dont_know", "Do not know"),
                    ("DWTA", "Don't want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                help_text="in local currency",
                max_length=25,
                verbose_name="If the owner [you] were to sell this dwelling today, do you know the approximate value?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsassets",
            name="rooms",
            field=models.IntegerField(
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(30),
                ],
                verbose_name="How many rooms does your dwelling have in total, without counting the bathrooms/ toilets or hallways/passageways?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="interest_value",
            field=models.IntegerField(
                blank=True,
                help_text="Use cash equivalent in local currency",
                null=True,
                verbose_name="Estimated <u>total amount of income</u> from this source over the time period from above",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="more_sources_value",
            field=models.IntegerField(
                blank=True,
                help_text="Use cash equivalent in local currency",
                null=True,
                verbose_name="Estimated <u>total amount of income</u> from this source over the time period from above",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="ngo_assistance_value",
            field=models.IntegerField(
                blank=True,
                help_text="Use cash equivalent in local currency",
                null=True,
                verbose_name="Estimated <u>total amount of income</u> from this source over the time period from above",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="pension_value",
            field=models.IntegerField(
                blank=True,
                help_text="Use cash equivalent in local currency",
                null=True,
                verbose_name="Estimated <u>total amount of income</u> from this source over the time period from above",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="rental_income_value",
            field=models.IntegerField(
                blank=True,
                help_text="Use cash equivalent in local currency",
                null=True,
                verbose_name="Estimated <u>total amount of income</u> from this source over the time period from above",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="selling_value",
            field=models.IntegerField(
                blank=True,
                help_text="Use cash equivalent in local currency",
                null=True,
                verbose_name="Estimated <u>total amount of income</u> from this source over the time period from above",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="wages_value",
            field=models.IntegerField(
                blank=True,
                help_text="Use cash equivalent in local currency",
                null=True,
                verbose_name="Estimated <u>total amount of income</u> from this source over the time period from above",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsassets",
            name="dwelling_value_known",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("dont_know", "Do not know"),
                    ("DWTA", "Don't want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                help_text="in local currency",
                max_length=25,
                verbose_name="If the owner [you] were to sell this dwelling today, do you know the approximate value?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsassets",
            name="rooms",
            field=models.IntegerField(
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(30),
                ],
                verbose_name="How many rooms does your dwelling have in total, without counting the bathrooms/ toilets or hallways/passageways?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="interest_value",
            field=models.IntegerField(
                blank=True,
                help_text="Use cash equivalent in local currency",
                null=True,
                verbose_name="Estimated <u>total amount of income</u> from this source over the time period from above",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="more_sources_value",
            field=models.IntegerField(
                blank=True,
                help_text="Use cash equivalent in local currency",
                null=True,
                verbose_name="Estimated <u>total amount of income</u> from this source over the time period from above",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="ngo_assistance_value",
            field=models.IntegerField(
                blank=True,
                help_text="Use cash equivalent in local currency",
                null=True,
                verbose_name="Estimated <u>total amount of income</u> from this source over the time period from above",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="pension_value",
            field=models.IntegerField(
                blank=True,
                help_text="Use cash equivalent in local currency",
                null=True,
                verbose_name="Estimated <u>total amount of income</u> from this source over the time period from above",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="rental_income_value",
            field=models.IntegerField(
                blank=True,
                help_text="Use cash equivalent in local currency",
                null=True,
                verbose_name="Estimated <u>total amount of income</u> from this source over the time period from above",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="selling_value",
            field=models.IntegerField(
                blank=True,
                help_text="Use cash equivalent in local currency",
                null=True,
                verbose_name="Estimated <u>total amount of income</u> from this source over the time period from above",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="wages_value",
            field=models.IntegerField(
                blank=True,
                help_text="Use cash equivalent in local currency",
                null=True,
                verbose_name="Estimated <u>total amount of income</u> from this source over the time period from above",
            ),
        ),
    ]
