# Generated by Django 4.2.3 on 2023-08-03 16:18

from django.conf import settings
from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ("edc_he", "0004_historicalemployment_historicaleducation_employment_and_more"),
    ]

    operations = [
        migrations.RenameModel(
            old_name="Employment",
            new_name="EmploymentType",
        ),
        migrations.RenameModel(
            old_name="HistoricalEmployment",
            new_name="HistoricalEmploymentType",
        ),
        migrations.AlterModelOptions(
            name="employmenttype",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "ordering": ["display_index", "display_name"],
                "verbose_name": "Employment type",
                "verbose_name_plural": "Employment types",
            },
        ),
        migrations.AlterModelOptions(
            name="historicalemploymenttype",
            options={
                "get_latest_by": ("history_date", "history_id"),
                "ordering": ("-history_date", "-history_id"),
                "verbose_name": "historical Employment type",
                "verbose_name_plural": "historical Employment types",
            },
        ),
        migrations.RenameIndex(
            model_name="employmenttype",
            new_name="edc_he_empl_id_810a9e_idx",
            old_name="edc_he_empl_id_3d6790_idx",
        ),
    ]
